# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdWatermark(Component):
    """An AntdWatermark component.
    水印组件AntdWatermark

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string; optional):
        当前组件css类名.

    - markClassName (string; optional):
        水印层css类名.

    - markStyle (dict; optional):
        水印层css样式.

    - content (string | list of strings; optional):
        配置水印内容，传入数组时渲染多行水印.

    - rotate (number; default -22):
        水印旋转角度 默认值：`-22`.

    - zIndex (number; optional):
        水印z-index.

    - fontColor (string; optional):
        文字水印颜色.

    - fontSize (number; default 16):
        文字水印字体大小 默认值：`16`.

    - gapX (number; default 212):
        水印之间的水平像素间距 默认值：`212`.

    - gapY (number; default 222):
        水印之间的垂直像素间距 默认值：`222`.

    - image (string; optional):
        图片水印地址.

    - width (number; optional):
        图片水印像素宽度.

    - height (number; optional):
        图片水印像素高度.

    - inherit (boolean; default True):
        是否将水印传导给`AntdModal`、`AntdDrawer`等弹出类组件 默认值：`True`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdWatermark'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[str] = None,
        markClassName: typing.Optional[str] = None,
        markStyle: typing.Optional[dict] = None,
        content: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rotate: typing.Optional[NumberType] = None,
        zIndex: typing.Optional[NumberType] = None,
        fontColor: typing.Optional[str] = None,
        fontSize: typing.Optional[NumberType] = None,
        gapX: typing.Optional[NumberType] = None,
        gapY: typing.Optional[NumberType] = None,
        image: typing.Optional[str] = None,
        width: typing.Optional[NumberType] = None,
        height: typing.Optional[NumberType] = None,
        inherit: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'markClassName',
            'markStyle',
            'content',
            'rotate',
            'zIndex',
            'fontColor',
            'fontSize',
            'gapX',
            'gapY',
            'image',
            'width',
            'height',
            'inherit',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'markClassName',
            'markStyle',
            'content',
            'rotate',
            'zIndex',
            'fontColor',
            'fontSize',
            'gapX',
            'gapY',
            'image',
            'width',
            'height',
            'inherit',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdWatermark, self).__init__(children=children, **args)


setattr(AntdWatermark, '__init__', _explicitize_args(AntdWatermark.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdInputNumber(Component):
    """An AntdInputNumber component.
    数值输入框组件AntdInputNumber

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - addonBefore (a list of or a singular dash component, string or number; optional):
        组件型，前置标签内容.

    - addonAfter (a list of or a singular dash component, string or number; optional):
        组件型，后置标签内容.

    - prefix (a list of or a singular dash component, string or number; optional):
        组件型，前缀内嵌内容.

    - suffix (a list of or a singular dash component, string or number; optional):
        组件型，后缀内嵌内容.

    - autoFocus (boolean; default False):
        是否自动获取焦点 默认值：`False`.

    - controls (boolean; default True):
        是否显示增减数值按钮 默认值：`True`.

    - keyboard (boolean; default True):
        是否允许通过键盘上下方向键控制数值 默认值：`True`.

    - min (number | string; optional):
        允许输入的数值下限，默认无限制.

    - max (number | string; optional):
        允许输入的数值上限，默认无限制.

    - step (number | string; optional):
        数值增减步长.

    - precision (number; optional):
        数值精度.

    - stringMode (boolean; default False):
        是否开启字符串模式，用于在接受超高精度数值输入时不丢失精度，开启后，参数`min`、`max`、`step`、`value`、`defaultValue`均需要设置为字符型
        默认值：`False`.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

    - placeholder (string; optional):
        输入框占位文字内容.

    - value (number | string; optional):
        监听或设置已输入值.

    - defaultValue (number | string; optional):
        初始化已输入值.

    - debounceValue (number | string; optional):
        监听防抖版本的已输入值.

    - debounceWait (number; default 0):
        防抖延时时长，单位：毫秒 默认值：`0`.

    - nSubmit (number; default 0):
        监听输入框聚焦状态下，键盘enter键累计点按次数 默认值：`0`.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - readOnly (boolean; optional):
        是否渲染为只读状态 默认值：`False`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; default ['value']):
        开启属性持久化功能的若干属性名，可选项有`'md5Value'` 默认值：`['md5Value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['addonBefore', 'addonAfter', 'prefix', 'suffix']
    _base_nodes = ['addonBefore', 'addonAfter', 'prefix', 'suffix', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdInputNumber'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        addonBefore: typing.Optional[ComponentType] = None,
        addonAfter: typing.Optional[ComponentType] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffix: typing.Optional[ComponentType] = None,
        autoFocus: typing.Optional[bool] = None,
        controls: typing.Optional[bool] = None,
        keyboard: typing.Optional[bool] = None,
        min: typing.Optional[typing.Union[NumberType, str]] = None,
        max: typing.Optional[typing.Union[NumberType, str]] = None,
        step: typing.Optional[typing.Union[NumberType, str]] = None,
        precision: typing.Optional[NumberType] = None,
        stringMode: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        value: typing.Optional[typing.Union[NumberType, str]] = None,
        defaultValue: typing.Optional[typing.Union[NumberType, str]] = None,
        debounceValue: typing.Optional[typing.Union[NumberType, str]] = None,
        debounceWait: typing.Optional[NumberType] = None,
        nSubmit: typing.Optional[NumberType] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        readOnly: typing.Optional[bool] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'addonBefore',
            'addonAfter',
            'prefix',
            'suffix',
            'autoFocus',
            'controls',
            'keyboard',
            'min',
            'max',
            'step',
            'precision',
            'stringMode',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'value',
            'defaultValue',
            'debounceValue',
            'debounceWait',
            'nSubmit',
            'status',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'addonBefore',
            'addonAfter',
            'prefix',
            'suffix',
            'autoFocus',
            'controls',
            'keyboard',
            'min',
            'max',
            'step',
            'precision',
            'stringMode',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'value',
            'defaultValue',
            'debounceValue',
            'debounceWait',
            'nSubmit',
            'status',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdInputNumber, self).__init__(**args)


setattr(AntdInputNumber, '__init__', _explicitize_args(AntdInputNumber.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSpin(Component):
    """An AntdSpin component.
    加载动画组件AntdSpin

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - wrapperClassName (string | dict; optional):
        外层容器css类名.

    - spinning (boolean; default False):
        是否处于加载中状态.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        默认加载状态图标的尺寸，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - delay (number; optional):
        加载动画渲染延时，单位：毫秒 默认值：`0`.

    - text (string; optional):
        加载动画提示文字.

    - fullscreen (boolean; default False):
        是否开启全屏模式 默认值：`False`.

    - debug (boolean; default False):
        是否开启debug模式，开启后，每次动画加载都会在开发者工具的控制台打印相关`prop`信息 默认值：`False`.

    - listenPropsMode (a value equal to: 'default', 'exclude', 'include'; default 'default'):
        监听模式，可选项有`'default'`、`'exclude'`、`'include'` 默认值：`'default'`.

    - excludeProps (list of strings; optional):
        `listenPropsMode='exclude'`时，设置需要排除监听的回调目标列表，格式如`['组件id1.组件属性1',
        '组件id2.组件属性2', ...]`.

    - includeProps (list of strings; optional):
        `listenPropsMode='include'`时，设置需要包含监听的回调目标列表，格式如`['组件id1.组件属性1',
        '组件id2.组件属性2', ...]`.

    - indicator (a list of or a singular dash component, string or number; optional):
        组件型，自定义加载状态图标.

    - manual (boolean; default False):
        是否开启手动控制模式，开启后是否处于加载状态将由`spinning`参数控制，与内部元素参与的回调状态无关 默认值：`False`.

    - percent (number | a value equal to: 'auto'; optional):
        控制加载中状态下的环状进度渲染形式，传入0到100之间数值型时表示实际进度，传入`'auto'`时会预估一个永远不会停止的进度.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['indicator']
    _base_nodes = ['indicator', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSpin'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        wrapperClassName: typing.Optional[typing.Union[str, dict]] = None,
        spinning: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        delay: typing.Optional[NumberType] = None,
        text: typing.Optional[str] = None,
        fullscreen: typing.Optional[bool] = None,
        debug: typing.Optional[bool] = None,
        listenPropsMode: typing.Optional[Literal['default', 'exclude', 'include']] = None,
        excludeProps: typing.Optional[typing.Sequence[str]] = None,
        includeProps: typing.Optional[typing.Sequence[str]] = None,
        indicator: typing.Optional[ComponentType] = None,
        manual: typing.Optional[bool] = None,
        percent: typing.Optional[typing.Union[NumberType, Literal['auto']]] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'wrapperClassName',
            'spinning',
            'size',
            'delay',
            'text',
            'fullscreen',
            'debug',
            'listenPropsMode',
            'excludeProps',
            'includeProps',
            'indicator',
            'manual',
            'percent',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'wrapperClassName',
            'spinning',
            'size',
            'delay',
            'text',
            'fullscreen',
            'debug',
            'listenPropsMode',
            'excludeProps',
            'includeProps',
            'indicator',
            'manual',
            'percent',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSpin, self).__init__(children=children, **args)


setattr(AntdSpin, '__init__', _explicitize_args(AntdSpin.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSplitter(Component):
    """An AntdSplitter component.
    分隔面板组件AntdSplitter

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - layout (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
        布局方向，可选项有`'horizontal'`、`'vertical'` 默认值：`'horizontal'`.

    - items (list of dicts; required):
        配置分隔面板子项.

        `items` is a list of dicts with keys:

        - key (string; optional):
            当前子项唯一识别`key`.

        - children (a list of or a singular dash component, string or number; optional):
            组件型，内嵌元素.

        - style (dict; optional):
            当前子项`css`样式.

        - className (string; optional):
            当前子项`css`类名.

        - defaultSize (number

          Or string; optional):
            初始面板尺寸，支持数字`px`或者文字`'百分比%'`类型.

        - size (number | string; optional):
            面板尺寸，支持数字`px`或者文字`'百分比%'`类型.

        - min (number | string; optional):
            最小尺寸，支持数字`px`或者文字`'百分比%'`类型.

        - max (number | string; optional):
            最大尺寸，支持数字`px`或者文字`'百分比%'`类型.

        - collapsible (dict; optional):
            是否可折叠 默认值：`False`.

            `collapsible` is a boolean | dict with keys:

            - start (boolean; optional)

            - end (boolean; optional)

        - resizable (boolean; optional):
            是否开启拖拽伸缩 默认值：`True`.

    - lazy (boolean; default False):
        是否开启延迟渲染模式，开启后面板将在拖拽调整完成后才进行更新渲染 默认值：`False`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['items[].children']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSplitter'
    ItemsCollapsible = TypedDict(
        'ItemsCollapsible', {'start': NotRequired[bool], 'end': NotRequired[bool]}
    )

    Items = TypedDict(
        'Items',
        {
            'key': NotRequired[str],
            'children': NotRequired[ComponentType],
            'style': NotRequired[dict],
            'className': NotRequired[str],
            'defaultSize': NotRequired[typing.Union[NumberType, str]],
            'size': NotRequired[typing.Union[NumberType, str]],
            'min': NotRequired[typing.Union[NumberType, str]],
            'max': NotRequired[typing.Union[NumberType, str]],
            'collapsible': NotRequired[typing.Union[bool, 'ItemsCollapsible']],
            'resizable': NotRequired[bool],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        layout: typing.Optional[Literal['horizontal', 'vertical']] = None,
        items: typing.Optional[typing.Sequence['Items']] = None,
        lazy: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'layout',
            'items',
            'lazy',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'layout',
            'items',
            'lazy',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['items']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdSplitter, self).__init__(**args)


setattr(AntdSplitter, '__init__', _explicitize_args(AntdSplitter.__init__))



all_icons = [
    'antd-carry-out',
    'antd-car',
    'antd-bulb',
    'antd-build',
    'antd-bug',
    'antd-bar-code',
    'antd-branches',
    'antd-aim',
    'antd-issues-close',
    'antd-ellipsis',
    'antd-user',
    'antd-unlock',
    'antd-repair',
    'antd-team',
    'antd-sync',
    'antd-setting',
    'antd-send',
    'antd-schedule',
    'antd-save',
    'antd-rocket',
    'antd-reload',
    'antd-read',
    'antd-qrcode',
    'antd-power-off',
    'antd-number',
    'antd-notification',
    'antd-menu',
    'antd-mail',
    'antd-lock',
    'antd-loading',
    'antd-key',
    'antd-hourglass',
    'antd-global',
    'antd-function',
    'antd-import',
    'antd-export',
    'antd-dashboard',
    'antd-control',
    'antd-console-sql',
    'antd-compass',
    'antd-comment',
    'antd-code',
    'antd-cluster',
    'antd-clear',
    'antd-camera',
    'antd-book',
    'antd-catalog',
    'antd-api',
    'antd-alert',
    'antd-account-book',
    'antd-alipay',
    'antd-alipay-circle',
    'antd-weibo',
    'antd-github',
    'antd-android',
    'antd-apple',
    'antd-wechat',
    'antd-wechat-work',
    'antd-openai',
    'antd-bilibili',
    'antd-tiktok',
    'antd-javascript',
    'antd-python',
    'antd-docker',
    'antd-fall',
    'antd-rise',
    'antd-stock',
    'antd-home',
    'antd-fund',
    'antd-area-chart',
    'antd-radar-chart',
    'antd-bar-chart',
    'antd-pie-chart',
    'antd-box-plot',
    'antd-dot-chart',
    'antd-line-chart',
    'antd-field-binary',
    'antd-field-number',
    'antd-field-string',
    'antd-field-time',
    'antd-file-add',
    'antd-file-done',
    'antd-file',
    'antd-file-image',
    'antd-file-markdown',
    'antd-file-pdf',
    'antd-file-protect',
    'antd-file-sync',
    'antd-file-text',
    'antd-file-word',
    'antd-file-zip',
    'antd-filter',
    'antd-fire',
    'antd-woman',
    'antd-arrow-up',
    'antd-arrow-down',
    'antd-arrow-left',
    'antd-arrow-right',
    'antd-flag',
    'antd-user-add',
    'antd-folder-add',
    'antd-man',
    'antd-tag',
    'antd-folder',
    'antd-user-delete',
    'antd-trophy',
    'antd-shopping-cart',
    'antd-folder-open',
    'antd-fork',
    'antd-select',
    'antd-tags',
    'antd-thunderbolt',
    'antd-sound',
    'antd-fund-projection-screen',
    'antd-funnel-plot',
    'antd-gift',
    'antd-robot',
    'antd-pushpin',
    'antd-printer',
    'antd-phone',
    'antd-picture',
    'antd-idcard',
    'antd-partition',
    'antd-monitor',
    'antd-more',
    'antd-apartment',
    'antd-money-collect',
    'antd-experiment',
    'antd-link',
    'antd-mobile',
    'antd-coffee',
    'antd-layout',
    'antd-eye',
    'antd-eye-invisible',
    'antd-exception',
    'antd-dollar',
    'antd-euro',
    'antd-download',
    'antd-environment',
    'antd-deployment-unit',
    'antd-crown',
    'antd-desktop',
    'antd-like',
    'antd-dislike',
    'antd-disconnect',
    'antd-app-store',
    'antd-app-store-add',
    'antd-bell',
    'antd-calculator',
    'antd-calendar',
    'antd-database',
    'antd-history',
    'antd-search',
    'antd-file-search',
    'antd-cloud',
    'antd-cloud-upload',
    'antd-cloud-download',
    'antd-cloud-server',
    'antd-cloud-sync',
    'antd-swap',
    'antd-rollback',
    'antd-login',
    'antd-logout',
    'antd-menu-fold',
    'antd-menu-unfold',
    'antd-full-screen',
    'antd-full-screen-exit',
    'antd-question-circle',
    'antd-plus-circle',
    'antd-minus-circle',
    'antd-info-circle',
    'antd-exclamation-circle',
    'antd-close-circle',
    'antd-check-circle',
    'antd-clock-circle',
    'antd-stop',
    'antd-edit',
    'antd-delete',
    'antd-highlight',
    'antd-redo',
    'antd-undo',
    'antd-zoom-in',
    'antd-zoom-out',
    'antd-sort-ascending',
    'antd-sort-descending',
    'antd-table',
    'antd-question',
    'antd-plus',
    'antd-minus',
    'antd-close',
    'antd-check',
    'antd-sketch',
    'antd-bank',
    'antd-block',
    'antd-insurance',
    'antd-smile',
    'antd-skin',
    'antd-star',
    'antd-right-circle-two-tone',
    'antd-left-circle-two-tone',
    'antd-up-circle-two-tone',
    'antd-down-circle-two-tone',
    'antd-up-square-two-tone',
    'antd-down-square-two-tone',
    'antd-left-square-two-tone',
    'antd-right-square-two-tone',
    'antd-question-circle-two-tone',
    'antd-plus-circle-two-tone',
    'antd-minus-circle-two-tone',
    'antd-plus-square-two-tone',
    'antd-minus-square-two-tone',
    'antd-info-circle-two-tone',
    'antd-exclamation-circle-two-tone',
    'antd-close-circle-two-tone',
    'antd-close-square-two-tone',
    'antd-check-circle-two-tone',
    'antd-check-square-two-tone',
    'antd-edit-two-tone',
    'antd-delete-two-tone',
    'antd-highlight-two-tone',
    'antd-pie-chart-two-tone',
    'antd-box-chart-two-tone',
    'antd-fund-two-tone',
    'antd-sliders-two-tone',
    'antd-api-two-tone',
    'antd-cloud-two-tone',
    'antd-hourglass-two-tone',
    'antd-notification-two-tone',
    'antd-tool-two-tone',
    'antd-down',
    'antd-up',
    'antd-left',
    'antd-right',
    'antd-caret-up',
    'antd-caret-down',
    'antd-caret-left',
    'antd-caret-right',
    'antd-up-circle',
    'antd-down-circle',
    'antd-left-circle',
    'antd-right-circle',
    'antd-enter',
    'antd-retweet',
    'antd-warning',
    'antd-form',
    'antd-copy',
    'antd-scissor',
    'antd-snippets',
    'antd-diff',
    'antd-ordered-list',
    'antd-unordered-list',
    'antd-sliders',
    'antd-audit',
    'antd-border',
    'antd-contacts',
    'antd-container',
    'antd-delivered-procedure',
    'antd-pause',
    'antd-step-backward',
    'antd-step-forward',
    'antd-fast-forward',
    'antd-fast-backward',
    'antd-sun',
    'antd-mooon',
    'md-star-half',
    'md-star-border',
    'md-star',
    'md-people',
    'md-plus-one',
    'md-notifications',
    'md-pin-drop',
    'md-layers-clear',
    'md-layers',
    'md-edit-location',
    'md-tune',
    'md-transform',
    'md-timer-off',
    'md-timer',
    'md-file-upload',
    'md-file-download',
    'md-create-new-folder',
    'md-cloud-upload',
    'md-cloud-queue',
    'md-cloud-download',
    'md-cloud-done',
    'md-insert-chart',
    'md-functions',
    'md-format-quote',
    'md-attach-file',
    'md-storage',
    'md-save',
    'md-remove-circle-outline',
    'md-remove-circle',
    'md-remove',
    'md-low-priority',
    'md-link',
    'md-gesture',
    'md-forward',
    'md-flag',
    'md-drafts',
    'md-create',
    'md-content-paste',
    'md-content-cut',
    'md-content-copy',
    'md-clear',
    'md-block',
    'md-backspace',
    'md-add-box',
    'md-add',
    'md-add-circle-outline',
    'md-add-circle',
    'md-location-on',
    'md-mail-outline',
    'md-email',
    'md-not-interested',
    'md-library-books',
    'md-library-add',
    'md-equalizer',
    'md-add-alert',
    'md-visibility-off',
    'md-visibility',
    'md-verified-user',
    'md-update',
    'md-trending-up',
    'md-trending-flat',
    'md-trending-down',
    'md-translate',
    'md-toc',
    'md-timeline',
    'md-thumb-up',
    'md-thumb-down',
    'md-swap-vert',
    'md-swap-horiz',
    'md-supervisor-account',
    'md-subject',
    'md-settings',
    'md-search',
    'md-schedule',
    'md-restore',
    'md-query-builder',
    'md-power-settings-new',
    'md-opacity',
    'md-note-add',
    'md-lock-outline',
    'md-lock-open',
    'md-list',
    'md-lightbulb-outline',
    'md-launch',
    'md-label-outline',
    'md-label',
    'md-input',
    'md-info-outline',
    'md-info',
    'md-hourglass',
    'md-home',
    'md-history',
    'md-highlight-off',
    'md-help-outline',
    'md-help',
    'md-get-app',
    'md-translate',
    'md-fingerprint',
    'md-findIn-page',
    'md-favorite-border',
    'md-favorite',
    'md-extension',
    'md-explore',
    'md-exit-to-app',
    'md-event',
    'md-description',
    'md-delete-forever',
    'md-delete',
    'md-dashboard',
    'md-code',
    'md-build',
    'md-bug-report',
    'md-assignment',
    'md-assessment',
    'md-alarm-on',
    'md-alarm-off',
    'md-alarm-add',
    'md-alarm',
    'md-account-circle',
    'fc-vlc',
    'fc-view-details',
    'fc-upload',
    'fc-tree-structure',
    'fc-timeline',
    'fc-template',
    'fc-survey',
    'fc-signature',
    'fc-share',
    'fc-services',
    'fc-rules',
    'fc-questions',
    'fc-process',
    'fc-plus',
    'fc-overtime',
    'fc-organization',
    'fc-numerical-sorting21',
    'fc-numerical-sorting12',
    'fc-multiple-inputs',
    'fc-mind-map',
    'fc-menu',
    'fc-list',
    'fc-like',
    'fc-like-placeholder',
    'fc-info',
    'fc-import',
    'fc-image-file',
    'fc-idea',
    'fc-home',
    'fc-high-priority',
    'fc-low-priority',
    'fc-genealogy',
    'fc-full-trash',
    'fc-document-search',
    'fc-file',
    'fc-faq',
    'fc-export',
    'fc-empty-trash',
    'fc-download',
    'fc-document',
    'fc-deployment',
    'fc-delete-database',
    'fc-conference-call',
    'fc-database',
    'fc-data-protection',
    'fc-data-encryption',
    'fc-data-configuration',
    'fc-data-backup',
    'fc-checkmark',
    'fc-cancel',
    'fc-briefcase',
    'fc-binoculars',
    'fc-automatic',
    'fc-alphabetical-sorting-za',
    'fc-alphabetical-sorting-az',
    'fc-add-database',
    'fc-accept-database',
    'fc-about',
    'fc-radar-chart',
    'fc-scatter-chart',
    'fc-pie-chart',
    'fc-line-chart',
    'fc-flow-chart',
    'fc-doughnut-chart',
    'fc-bar-chart',
    'fc-area-chart',
    'fc-line-bar-chart',
    'fc-workflow',
    'fc-todo-list',
    'fc-synchronize',
    'fc-repair',
    'fc-statistics',
    'fc-settings',
    'fc-search',
    'fc-serial-tasks',
    'fc-safe',
    'fc-negative-dynamic',
    'fc-positive-dynamic',
    'fc-planner',
    'fc-parallel-tasks',
    'fc-org-unit',
    'fc-opened-folder',
    'fc-ok',
    'fc-inspection',
    'fc-globe',
    'fc-folder',
    'fc-electronics',
    'fc-data-sheet',
    'fc-command-line',
    'fc-calendar',
    'fc-calculator',
    'fc-bullish',
    'fc-bearish',
    'fc-bookmark',
    'fc-approval',
    'fc-advertising',
    'di-linux',
    'di-python',
    'di-chrome',
    'di-database',
    'di-firefox',
    'di-markdown',
    'di-postgresql',
    'di-terminal',
    'di-windows',
    'bi-table',
    'bi-analyse',
    'bi-layer',
    'bi-layer-minus',
    'bi-layer-plus',
    'bs-list-task',
    'bs-list-check',
    'bs-link',
    'bs-link-45-deg',
    'bs-envelope-open',
    'bs-envelope',
    'bs-alarm',
    'im-earth',
    'im-sphere',
    'gi-mesh-network',
    'pi-circle',
    'pi-polygon',
    'pi-map-pin',
    'pi-line-segment',
    'pi-line-segments',
    'pi-trash-simple',
    'pi-trash',
    'pi-ruler',
    'pi-selection',
    'pi-selection-slash',
    'pi-square-split-horizontal',
    'pi-square-split-vertical',
    'pi-stack-simple',
    'pi-stack',
    'pi-navigation-arrow',
    'pi-map-trifold',
    'pi-info',
    'pi-lock-key-open',
    'pi-lock-key',
    'pi-gear',
    'pi-airplane',
    'pi-anchor-simple',
    'pi-arrow-arc-left',
    'pi-arrow-arc-right',
    'pi-arrow-clockwise',
    'pi-arrow-counter-clockwise',
    'pi-barricade',
    'pi-binoculars',
    'pi-bounding-box',
    'pi-broom',
    'pi-buildings',
    'pi-calculator',
    'pi-camera',
    'pi-circuitry',
    'pi-clipboard',
    'pi-compass',
    'pi-copy',
    'pi-cpu',
    'pi-crosshair',
    'pi-cube-focus',
    'pi-cube',
    'pi-cursor',
    'pi-database',
    'pi-eye-slash',
    'pi-eye',
    'pi-faders',
    'pi-floppy-disk',
    'pi-dots-three-vertical',
    'pi-dots-three',
    'pi-math-operations',
    'pi-plus',
    'pi-minus',
    'pi-path',
    'si-gitee',
]



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdPagination(Component):
    """An AntdPagination component.
    分页组件AntdPagination

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - align (a value equal to: 'start', 'center', 'end'; default 'start'):
        组件尺寸规格，可选项有`'start'`、`'center'`、`'end'` 默认值：`'start'`.

    - defaultCurrent (number; default 1):
        初始化时的当前页码 默认值：`1`.

    - defaultPageSize (number; default 10):
        初始化时的每页条数 默认值：`10`.

    - current (number; optional):
        监听或设置当前页码.

    - disabled (boolean; default False):
        是否禁用当前组件功能 默认值：`False`.

    - hideOnSinglePage (boolean; default False):
        仅有一页时是否隐藏分页器 默认值：`False`.

    - pageSize (number; optional):
        监听或设置每页条数.

    - pageSizeOptions (list of numbers; optional):
        每页条数切换可选项.

    - showSizeChanger (boolean; default False):
        是否渲染每页条数切换器 默认值：`False`.

    - showQuickJumper (boolean; default False):
        是否渲染快捷跳页控件 默认值：`False`.

    - showTotalPrefix (string; optional):
        总记录数描述前缀内容.

    - showTotalSuffix (string; optional):
        总记录数描述后缀内容.

    - simple (boolean; default False):
        是否启用简洁模式 默认值：`False`.

    - size (a value equal to: 'default', 'small'; default 'default'):
        组件尺寸规格，可选项有`'default'`、`'small'` 默认值：`'default'`.

    - total (number; optional):
        总记录数.

    - showTotal (boolean; default True):
        是否渲染总记录数描述内容 默认值：`True`.

    - showLessItems (boolean; default False):
        是否显示较少的跳页按钮 默认值：`False`.

    - batchPropsNames (list of strings; optional):
        需要纳入批属性监听的属性名 默认值：`[]`.

    - batchPropsValues (dict; optional):
        批量监听与当前batchPropsNames对应的属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否为当前组件开启持久化功能.

    - persisted_props (list of a value equal to: 'current', 'pageSize's; optional):
        当前组件启用持久化的属性值数组，可选项有`'current'`、`'pageSize'` 默认值：`['current',
        'pageSize']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        当前组件的属性持久化存储类型 默认值：`'local'`."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdPagination'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        align: typing.Optional[Literal['start', 'center', 'end']] = None,
        defaultCurrent: typing.Optional[NumberType] = None,
        defaultPageSize: typing.Optional[NumberType] = None,
        current: typing.Optional[NumberType] = None,
        disabled: typing.Optional[bool] = None,
        hideOnSinglePage: typing.Optional[bool] = None,
        pageSize: typing.Optional[NumberType] = None,
        pageSizeOptions: typing.Optional[typing.Sequence[NumberType]] = None,
        showSizeChanger: typing.Optional[bool] = None,
        showQuickJumper: typing.Optional[bool] = None,
        showTotalPrefix: typing.Optional[str] = None,
        showTotalSuffix: typing.Optional[str] = None,
        simple: typing.Optional[bool] = None,
        size: typing.Optional[Literal['default', 'small']] = None,
        total: typing.Optional[NumberType] = None,
        showTotal: typing.Optional[bool] = None,
        showLessItems: typing.Optional[bool] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['current', 'pageSize']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'align',
            'defaultCurrent',
            'defaultPageSize',
            'current',
            'disabled',
            'hideOnSinglePage',
            'pageSize',
            'pageSizeOptions',
            'showSizeChanger',
            'showQuickJumper',
            'showTotalPrefix',
            'showTotalSuffix',
            'simple',
            'size',
            'total',
            'showTotal',
            'showLessItems',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'align',
            'defaultCurrent',
            'defaultPageSize',
            'current',
            'disabled',
            'hideOnSinglePage',
            'pageSize',
            'pageSizeOptions',
            'showSizeChanger',
            'showQuickJumper',
            'showTotalPrefix',
            'showTotalSuffix',
            'simple',
            'size',
            'total',
            'showTotal',
            'showLessItems',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdPagination, self).__init__(**args)


setattr(AntdPagination, '__init__', _explicitize_args(AntdPagination.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdPageHeader(Component):
    """An AntdPageHeader component.
    页头组件AntdPageHeader

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - title (a list of or a singular dash component, string or number; optional):
        组件型，页头标题内容.

    - subTitle (a list of or a singular dash component, string or number; optional):
        组件型，页头副标题内容.

    - showBackIcon (boolean; default True):
        是否渲染返回按钮 默认值：`True`.

    - historyBackDisabled (boolean; default False):
        是否禁用点击返回按钮回退上一地址的功能 默认值：`False`.

    - backClicks (number; default 0):
        返回按钮累计点击次数，用于监听返回按钮点击行为 默认值：`0`.

    - ghost (boolean; default False):
        是否开启透明背景模式 默认值：`False`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['title', 'subTitle']
    _base_nodes = ['title', 'subTitle', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdPageHeader'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        title: typing.Optional[ComponentType] = None,
        subTitle: typing.Optional[ComponentType] = None,
        showBackIcon: typing.Optional[bool] = None,
        historyBackDisabled: typing.Optional[bool] = None,
        backClicks: typing.Optional[NumberType] = None,
        ghost: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'title',
            'subTitle',
            'showBackIcon',
            'historyBackDisabled',
            'backClicks',
            'ghost',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'title',
            'subTitle',
            'showBackIcon',
            'historyBackDisabled',
            'backClicks',
            'ghost',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdPageHeader, self).__init__(children=children, **args)


setattr(AntdPageHeader, '__init__', _explicitize_args(AntdPageHeader.__init__))



from dash import Dash, html
from feffery_dash_utils.style_utils import style

import feffery_antd_components as fac


def test_basic_usage(dash_duo):
    app = Dash(__name__)
    app.layout = html.Div(
        fac.AntdButton(fac.__version__, id='button-demo', type='primary'),
        style=style(padding=50),
    )

    dash_duo.start_server(app)

    dash_duo.wait_for_text_to_equal(
        '#button-demo',
        fac.__version__,
    )



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSegmentedColoring(Component):
    """An AntdSegmentedColoring component.
    分段着色组件AntdSegmentedColoring

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - breakpoints (list of numbers; required):
        必填，监听或设置分段断点数组.

    - colors (list of strings; required):
        必填，为各分段设置颜色，数组长度应为`breakpoints`长度减1.

    - controls (boolean; default True):
        是否为各分段数值输入框添加增减按钮 默认值：`True`.

    - keyboard (boolean; default True):
        是否可通过键盘上下方向键增减各分段数值输入框数值 默认值：`True`.

    - min (number; optional):
        各分段数值输入框允许输入数值下限，默认无限制.

    - max (number; optional):
        各分段数值输入框允许输入数值上限，默认无限制.

    - step (number; default 0.01):
        各分段数值输入框数值调整步长 默认值：`0.01`.

    - precision (number; default 2):
        各分段数值输入框数值精度 默认值：`2`.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

    - placeholder (string; optional):
        各分段数值输入框占位文字内容.

    - readOnly (boolean; optional):
        是否渲染为只读状态 默认值：`False`.

    - pureLegend (boolean; default False):
        是否开启纯图例模式 默认值：`False`.

    - inputNumberStyle (dict; optional):
        各分段数值输入框统一css样式.

    - colorBlockStyle (dict; optional):
        色块css样式.

    - colorBlockPosition (a value equal to: 'left', 'right'; default 'right'):
        色块显示方位，可选项有`'left'`、`'right'` 默认值：`'right'`.

    - colorBlockClickEvent (dict; optional):
        监听分段色块点击事件.

        `colorBlockClickEvent` is a dict with keys:

        - color (string; optional):
            被点击色块的颜色值.

        - range (list of numbers; optional):
            被点击色块对应范围值.

        - timestamp (number; optional):
            事件对应时间戳.

    - pureLegendLabelStyle (dict; optional):
        当`pureLegend=True`时，设置各分段数值统一css样式.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSegmentedColoring'
    ColorBlockClickEvent = TypedDict(
        'ColorBlockClickEvent',
        {
            'color': NotRequired[str],
            'range': NotRequired[typing.Sequence[NumberType]],
            'timestamp': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        breakpoints: typing.Optional[typing.Sequence[NumberType]] = None,
        colors: typing.Optional[typing.Sequence[str]] = None,
        controls: typing.Optional[bool] = None,
        keyboard: typing.Optional[bool] = None,
        min: typing.Optional[NumberType] = None,
        max: typing.Optional[NumberType] = None,
        step: typing.Optional[NumberType] = None,
        precision: typing.Optional[NumberType] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        readOnly: typing.Optional[bool] = None,
        pureLegend: typing.Optional[bool] = None,
        inputNumberStyle: typing.Optional[dict] = None,
        colorBlockStyle: typing.Optional[dict] = None,
        colorBlockPosition: typing.Optional[Literal['left', 'right']] = None,
        colorBlockClickEvent: typing.Optional['ColorBlockClickEvent'] = None,
        pureLegendLabelStyle: typing.Optional[dict] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'breakpoints',
            'colors',
            'controls',
            'keyboard',
            'min',
            'max',
            'step',
            'precision',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'readOnly',
            'pureLegend',
            'inputNumberStyle',
            'colorBlockStyle',
            'colorBlockPosition',
            'colorBlockClickEvent',
            'pureLegendLabelStyle',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'breakpoints',
            'colors',
            'controls',
            'keyboard',
            'min',
            'max',
            'step',
            'precision',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'readOnly',
            'pureLegend',
            'inputNumberStyle',
            'colorBlockStyle',
            'colorBlockPosition',
            'colorBlockClickEvent',
            'pureLegendLabelStyle',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['breakpoints', 'colors']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdSegmentedColoring, self).__init__(**args)


setattr(AntdSegmentedColoring, '__init__', _explicitize_args(AntdSegmentedColoring.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCascader(Component):
    """An AntdCascader component.
    级联选择组件AntdCascader

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - popupClassName (string; optional):
        展开菜单css类名.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - optionsMode (a value equal to: 'tree', 'flat'; default 'tree'):
        对应`options`格式的渲染模式，可选项有`'tree'`（树形模式）、`'flat'`（扁平模式） 默认值：`'tree'`.

    - options (list; required):
        定义构造级联选择所需的数据结构，与`optionsMode`一致.

    - optionsNodeKeyToLabel (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        针对级联结构中的指定节点，定义作为标题的组件型内容，优先级高于`options`中对应的`label`值.

    - optionFilterProp (a value equal to: 'value', 'label'; default 'label'):
        选项关键词搜索时的目标字段，可选项有`'value'`、`'label'` 默认值：`'label'`.

    - panelMode (boolean; default False):
        是否开启内嵌面板模式 默认值：`False`.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - changeOnSelect (boolean; default False):
        是否当级联选择中的任意节点被选择时均进行选中值更新 默认值：`False`.

    - size (a value equal to: 'small', 'middle', 'large'; optional):
        当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

    - placeholder (string; optional):
        输入框占位文字内容.

    - placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; default 'bottomLeft'):
        选择菜单展开方向，可选项有`'bottomLeft'`、`'bottomRight'`、`'topLeft'`、`'topRight'`
        默认值：`'bottomLeft'`.

    - value (list of string | numbers | list of list of string | numberss; optional):
        监听或设置已选值.

    - defaultValue (list of string | numbers | list of list of string | numberss; optional):
        初始化已选值.

    - multiple (boolean; default False):
        是否开启多选模式 默认值：`False`.

    - maxTagCount (number | a value equal to: 'responsive'; optional):
        当`multiple=True`时，已选值展示的最大数量.

    - expandTrigger (a value equal to: 'click', 'hover'; default 'click'):
        选择菜单展开触发方式，可选项有`'click'`、`'hover'` 默认值：`'click'`.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - allowClear (boolean; default True):
        是否允许一键清空已选值 默认值：`True`.

    - autoFocus (boolean; default False):
        是否自动获取焦点 默认值：`False`.

    - showCheckedStrategy (a value equal to: 'show-parent', 'show-child'; optional):
        已选项回填策略，可选项有`'show-parent'`、`'show-child'`.

    - prefix (a list of or a singular dash component, string or number; optional):
        组件型，前缀内嵌内容.

    - suffixIcon (a list of or a singular dash component, string or number; optional):
        自定义选择框后缀图标内容.

    - readOnly (boolean; optional):
        是否渲染为只读状态 默认值：`False`.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['optionsNodeKeyToLabel{}', 'prefix', 'suffixIcon']
    _base_nodes = ['prefix', 'suffixIcon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCascader'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        popupClassName: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        optionsMode: typing.Optional[Literal['tree', 'flat']] = None,
        options: typing.Optional[typing.Union[typing.Any, typing.Sequence[typing.Any]]] = None,
        optionsNodeKeyToLabel: typing.Optional[
            typing.Dict[typing.Union[str, float, int], ComponentType]
        ] = None,
        optionFilterProp: typing.Optional[Literal['value', 'label']] = None,
        panelMode: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        changeOnSelect: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        placement: typing.Optional[
            Literal['bottomLeft', 'bottomRight', 'topLeft', 'topRight']
        ] = None,
        value: typing.Optional[
            typing.Union[
                typing.Sequence[typing.Union[str, NumberType]],
                typing.Sequence[typing.Sequence[typing.Union[str, NumberType]]],
            ]
        ] = None,
        defaultValue: typing.Optional[
            typing.Union[
                typing.Sequence[typing.Union[str, NumberType]],
                typing.Sequence[typing.Sequence[typing.Union[str, NumberType]]],
            ]
        ] = None,
        multiple: typing.Optional[bool] = None,
        maxTagCount: typing.Optional[typing.Union[NumberType, Literal['responsive']]] = None,
        expandTrigger: typing.Optional[Literal['click', 'hover']] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        allowClear: typing.Optional[bool] = None,
        autoFocus: typing.Optional[bool] = None,
        showCheckedStrategy: typing.Optional[Literal['show-parent', 'show-child']] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffixIcon: typing.Optional[ComponentType] = None,
        readOnly: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'optionsMode',
            'options',
            'optionsNodeKeyToLabel',
            'optionFilterProp',
            'panelMode',
            'disabled',
            'changeOnSelect',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'value',
            'defaultValue',
            'multiple',
            'maxTagCount',
            'expandTrigger',
            'status',
            'allowClear',
            'autoFocus',
            'showCheckedStrategy',
            'prefix',
            'suffixIcon',
            'readOnly',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'optionsMode',
            'options',
            'optionsNodeKeyToLabel',
            'optionFilterProp',
            'panelMode',
            'disabled',
            'changeOnSelect',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'value',
            'defaultValue',
            'multiple',
            'maxTagCount',
            'expandTrigger',
            'status',
            'allowClear',
            'autoFocus',
            'showCheckedStrategy',
            'prefix',
            'suffixIcon',
            'readOnly',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['options']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdCascader, self).__init__(**args)


setattr(AntdCascader, '__init__', _explicitize_args(AntdCascader.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdMenu(Component):
    """An AntdMenu component.
    导航菜单组件AntdMenu

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - expandIcon (dict; optional):
        自定义展开图标，建议仅在`mode='inline'`时使用字典类型.

        `expandIcon` is a a list of or a singular dash component, string
        or number | dict with keys:

        - expand (a list of or a singular dash component, string or number; optional):
            展开图标.

        - collapse (a list of or a singular dash component, string or number; optional):
            收起图标.

    - menuItems (list; optional):
        导航菜单数据结构.

    - menuItemKeyToTitle (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        为指定节点定义组件型菜单项标题，优先级高于menuItems中对应节点的title属性.

    - menuItemKeyToIcon (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        为指定节点定义组件型菜单项图标元素，优先级高于menuItems中对应节点的icon属性.

    - mode (a value equal to: 'vertical', 'horizontal', 'inline'; default 'vertical'):
        显示模式，可选项有`'vertical'`、`'horizontal'`、`'inline'` 默认值：`'vertical'`.

    - theme (a value equal to: 'light', 'dark'; default 'light'):
        主题，可选项有`'light'`、`'dark'` 默认值：`'light'`.

    - currentKey (string; optional):
        监听或设置当前已选中菜单项key值.

    - currentItem (dict; optional):
        监听当前已选中菜单项信息.

    - currentKeyPath (list; optional):
        监听当前已选中菜单项key值路径信息.

    - currentItemPath (list; optional):
        监听当前已选中菜单项路径信息.

    - openKeys (list of strings; optional):
        监听或设置当前已展开子菜单项key值.

    - onlyExpandCurrentSubMenu (boolean; default False):
        是否只展开当前选中项的父级菜单 默认值：`False`.

    - defaultOpenKeys (list of strings; optional):
        默认展开的菜单项key值.

    - defaultSelectedKey (string; optional)

    - renderCollapsedButton (boolean; default False):
        是否渲染菜单折叠状态控制按钮 默认值：`False`.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        菜单展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - inlineCollapsed (boolean; optional):
        当前菜单是否折叠，仅inline模式下有效 默认值：`False`.

    - inlineIndent (number; default 24):
        inline模式下，子菜单相对上一级的像素缩进宽度 默认值：`24`.

    - triggerSubMenuAction (a value equal to: 'hover', 'click'; default 'hover'):
        `SubMenu`展开/关闭的触发行为，可选项有`'hover'`、`'click'`，`mode='inline'`下无效
        默认值：`'hover'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否为当前组件开启持久化功能.

    - persisted_props (list of a value equal to: 'currentKey', 'openKeys's; optional):
        当前组件启用持久化的属性值数组，可选项有`'currentKey'`、`'openKeys'`
        默认值：`['currentKey', 'openKeys']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        当前组件的属性持久化存储类型 默认值：`'local'`."""

    _children_props: typing.List[str] = [
        'expandIcon',
        'expandIcon.expand',
        'expandIcon.collapse',
        'menuItemKeyToTitle{}',
        'menuItemKeyToIcon{}',
    ]
    _base_nodes = ['expandIcon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdMenu'
    ExpandIcon = TypedDict(
        'ExpandIcon', {'expand': NotRequired[ComponentType], 'collapse': NotRequired[ComponentType]}
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        expandIcon: typing.Optional[typing.Union[ComponentType, 'ExpandIcon']] = None,
        menuItems: typing.Optional[typing.Sequence] = None,
        menuItemKeyToTitle: typing.Optional[
            typing.Dict[typing.Union[str, float, int], ComponentType]
        ] = None,
        menuItemKeyToIcon: typing.Optional[
            typing.Dict[typing.Union[str, float, int], ComponentType]
        ] = None,
        mode: typing.Optional[Literal['vertical', 'horizontal', 'inline']] = None,
        theme: typing.Optional[Literal['light', 'dark']] = None,
        currentKey: typing.Optional[str] = None,
        currentItem: typing.Optional[dict] = None,
        currentKeyPath: typing.Optional[typing.Sequence] = None,
        currentItemPath: typing.Optional[typing.Sequence] = None,
        openKeys: typing.Optional[typing.Sequence[str]] = None,
        onlyExpandCurrentSubMenu: typing.Optional[bool] = None,
        defaultOpenKeys: typing.Optional[typing.Sequence[str]] = None,
        defaultSelectedKey: typing.Optional[str] = None,
        renderCollapsedButton: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        inlineCollapsed: typing.Optional[bool] = None,
        inlineIndent: typing.Optional[NumberType] = None,
        triggerSubMenuAction: typing.Optional[Literal['hover', 'click']] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['currentKey', 'openKeys']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'expandIcon',
            'menuItems',
            'menuItemKeyToTitle',
            'menuItemKeyToIcon',
            'mode',
            'theme',
            'currentKey',
            'currentItem',
            'currentKeyPath',
            'currentItemPath',
            'openKeys',
            'onlyExpandCurrentSubMenu',
            'defaultOpenKeys',
            'defaultSelectedKey',
            'renderCollapsedButton',
            'popupContainer',
            'inlineCollapsed',
            'inlineIndent',
            'triggerSubMenuAction',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'expandIcon',
            'menuItems',
            'menuItemKeyToTitle',
            'menuItemKeyToIcon',
            'mode',
            'theme',
            'currentKey',
            'currentItem',
            'currentKeyPath',
            'currentItemPath',
            'openKeys',
            'onlyExpandCurrentSubMenu',
            'defaultOpenKeys',
            'defaultSelectedKey',
            'renderCollapsedButton',
            'popupContainer',
            'inlineCollapsed',
            'inlineIndent',
            'triggerSubMenuAction',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdMenu, self).__init__(**args)


setattr(AntdMenu, '__init__', _explicitize_args(AntdMenu.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCarousel(Component):
    """An AntdCarousel component.
    走马灯组件AntdCarousel

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，定义走马灯中需要轮播的若干元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - arrows (boolean; default False):
        是否显示箭头 默认值：`False`.

    - autoplay (dict; default False):
        是否自动轮播，可传入字典型进行更多配置 默认值：`False`.

        `autoplay` is a boolean | dict with keys:

        - dotDuration (boolean; optional):
            是否展示指示点进度条.

    - dotPosition (a value equal to: 'top', 'bottom', 'left', 'right'; default 'bottom'):
        面板指示器位置，可选项有`'top'`、`'bottom'`、`'left'`、`'right'` 默认值：`'bottom'`.

    - easing (string; default 'linear'):
        调整动画效果，同css中的`animation-timing-function` 默认值：'linear'.

    - effect (a value equal to: 'scrollx', 'fade'; default 'scrollx'):
        动化效果，可选项有`'scrollx'`、`'fade'` 默认值：'scrollx'.

    - autoplaySpeed (number; default 3000):
        轮播间隔时长，单位：毫秒 默认值：`3000`.

    - speed (number; default 500):
        轮播动画耗时，单位：毫秒 默认值：`500`.

    - pauseOnHover (boolean; default False):
        是否在鼠标悬停时暂停轮播 默认值：`False`.

    - infinite (boolean; default True):
        是否启用无限循环轮播 默认值：`True`.

    - lazyLoad (boolean; default False):
        是否针对走马灯中的子项实施懒加载效果 默认值：`False`.

    - slidesToShow (number; default 1):
        同时展示的子项数量 默认值：`1`.

    - slidesToScroll (number; default 1):
        一次轮播划过的子项数量 默认值：`1`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCarousel'
    Autoplay = TypedDict('Autoplay', {'dotDuration': NotRequired[bool]})

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        arrows: typing.Optional[bool] = None,
        autoplay: typing.Optional[typing.Union[bool, 'Autoplay']] = None,
        dotPosition: typing.Optional[Literal['top', 'bottom', 'left', 'right']] = None,
        easing: typing.Optional[str] = None,
        effect: typing.Optional[Literal['scrollx', 'fade']] = None,
        autoplaySpeed: typing.Optional[NumberType] = None,
        speed: typing.Optional[NumberType] = None,
        pauseOnHover: typing.Optional[bool] = None,
        infinite: typing.Optional[bool] = None,
        lazyLoad: typing.Optional[bool] = None,
        slidesToShow: typing.Optional[NumberType] = None,
        slidesToScroll: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'arrows',
            'autoplay',
            'dotPosition',
            'easing',
            'effect',
            'autoplaySpeed',
            'speed',
            'pauseOnHover',
            'infinite',
            'lazyLoad',
            'slidesToShow',
            'slidesToScroll',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'arrows',
            'autoplay',
            'dotPosition',
            'easing',
            'effect',
            'autoplaySpeed',
            'speed',
            'pauseOnHover',
            'infinite',
            'lazyLoad',
            'slidesToShow',
            'slidesToScroll',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCarousel, self).__init__(children=children, **args)


setattr(AntdCarousel, '__init__', _explicitize_args(AntdCarousel.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCheckCardGroup(Component):
    """An AntdCheckCardGroup component.
    组合选择卡片组件AntdCheckCardGroup

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌若干`AntdCheckCard`相关组件.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - multiple (boolean; default False):
        是否开启多选 默认值：`False`.

    - allowNoValue (boolean; default True):
        是否允许当前组合选择卡片中仅剩的选项被取消选中 默认值：`True`.

    - bordered (boolean; default True):
        是否显示边框 默认值：`True`.

    - value (number | string | list of number | strings; optional):
        监听或设置已选中卡片值.

    - defaultValue (number | string | list of number | strings; optional):
        初始化已选中卡片值.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - size (a value equal to: 'small', 'default', 'large'; default 'default'):
        当前组件尺寸规格，可选项有`'small'`、`'default'`、`'large'` 默认值：`'default'`.

    - readOnly (boolean; default False):
        是否渲染为只读状态 默认值：`False`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCheckCardGroup'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        multiple: typing.Optional[bool] = None,
        allowNoValue: typing.Optional[bool] = None,
        bordered: typing.Optional[bool] = None,
        value: typing.Optional[
            typing.Union[
                typing.Union[NumberType, str], typing.Sequence[typing.Union[NumberType, str]]
            ]
        ] = None,
        defaultValue: typing.Optional[
            typing.Union[
                typing.Union[NumberType, str], typing.Sequence[typing.Union[NumberType, str]]
            ]
        ] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'default', 'large']] = None,
        readOnly: typing.Optional[bool] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'multiple',
            'allowNoValue',
            'bordered',
            'value',
            'defaultValue',
            'disabled',
            'size',
            'readOnly',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'multiple',
            'allowNoValue',
            'bordered',
            'value',
            'defaultValue',
            'disabled',
            'size',
            'readOnly',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCheckCardGroup, self).__init__(children=children, **args)


setattr(AntdCheckCardGroup, '__init__', _explicitize_args(AntdCheckCardGroup.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdFormItem(Component):
    """An AntdFormItem component.
    表单项组件AntdFormItem

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌相关常用表单输入类组件.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - required (boolean; default False):
        是否显示表示必填项的额外“*”标识 默认值：`False`.

    - labelCol (dict; optional):
        配置表单项标签部分相关参数，优先级高于所属`AntdForm`中的`labelCol`参数.

        `labelCol` is a dict with keys:

        - span (number; optional):
            标签部分所占宽度份数（总份数24）.

        - offset (number; optional):
            标签部分向右偏移宽度份数.

        - flex (string | number; optional):
            同css中的flex属性，用于更灵活的控制标签部分所占宽度.

    - wrapperCol (dict; optional):
        配置表单项控件部分相关参数，优先级高于所属`AntdForm`中的`labelCol`参数.

        `wrapperCol` is a dict with keys:

        - span (number; optional):
            控件部分所占宽度份数（总份数24）.

        - offset (number; optional):
            控件部分向右偏移宽度份数.

        - flex (string | number; optional):
            同css中的flex属性，用于更灵活的控制控件部分所占宽度.

    - colon (boolean; optional):
        当`layout='horizontal'`时，控制是否在表单项标签部分末尾添加冒号，优先级高于所属`AntdForm`中的`colon`参数.

    - label (a list of or a singular dash component, string or number; optional):
        组件型，当前表单项标签内容.

    - labelAlign (a value equal to: 'left', 'right'; optional):
        表单项标签部分文本对齐方式，可选项有`'left'`、`'right'`，优先级高于所属`AntdForm`中的`labelAlign`参数
        默认值：`'right'`.

    - tooltip (a list of or a singular dash component, string or number; optional):
        组件型，当前表单项标签内容后的额外文字提示信息.

    - extra (a list of or a singular dash component, string or number; optional):
        组件型，当前表单项额外提示信息.

    - validateStatus (a value equal to: 'success', 'warning', 'error', 'validating'; optional):
        控制校验状态，可选项有`'success'`、`'warning'`、`'error'`、`'validating'`.

    - hasFeedback (boolean; default False):
        与`validateStatus`设定的状态对应，用于控制是否显示额外的状态图标 默认值：`False`.

    - help (a list of or a singular dash component, string or number; optional):
        组件型，与`validateStatus`状态一致的额外说明内容.

    - hidden (boolean; default False):
        是否隐藏当前字段 默认值：`False`.

    - layout (a value equal to: 'horizontal', 'vertical'; optional):
        表单项布局模式，可选项有`'horizontal'`、`'vertical'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['label', 'tooltip', 'extra', 'help']
    _base_nodes = ['label', 'tooltip', 'extra', 'help', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFormItem'
    LabelCol = TypedDict(
        'LabelCol',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'flex': NotRequired[typing.Union[str, NumberType]],
        },
    )

    WrapperCol = TypedDict(
        'WrapperCol',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'flex': NotRequired[typing.Union[str, NumberType]],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        required: typing.Optional[bool] = None,
        labelCol: typing.Optional['LabelCol'] = None,
        wrapperCol: typing.Optional['WrapperCol'] = None,
        colon: typing.Optional[bool] = None,
        label: typing.Optional[ComponentType] = None,
        labelAlign: typing.Optional[Literal['left', 'right']] = None,
        tooltip: typing.Optional[ComponentType] = None,
        extra: typing.Optional[ComponentType] = None,
        validateStatus: typing.Optional[
            Literal['success', 'warning', 'error', 'validating']
        ] = None,
        hasFeedback: typing.Optional[bool] = None,
        help: typing.Optional[ComponentType] = None,
        hidden: typing.Optional[bool] = None,
        layout: typing.Optional[Literal['horizontal', 'vertical']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'required',
            'labelCol',
            'wrapperCol',
            'colon',
            'label',
            'labelAlign',
            'tooltip',
            'extra',
            'validateStatus',
            'hasFeedback',
            'help',
            'hidden',
            'layout',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'required',
            'labelCol',
            'wrapperCol',
            'colon',
            'label',
            'labelAlign',
            'tooltip',
            'extra',
            'validateStatus',
            'hasFeedback',
            'help',
            'hidden',
            'layout',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdFormItem, self).__init__(children=children, **args)


setattr(AntdFormItem, '__init__', _explicitize_args(AntdFormItem.__init__))
